@@ -18,7 +18,8 @@ CONFIG_FILE_NAME = "active.json"
 ADVANCED_IMAGE_PROCESSING_FILE_TYPES = ["jpeg", "jpg", "png", "tiff", "bmp"]
 
 from mgmt_config import logger, storage_accounts
-storage_account = storage_accounts.get("main")
+storage_account = storage_accounts.get("main") if storage_accounts else None
+
 env_helper: EnvHelper = EnvHelper()
 log_execution = env_helper.LOG_EXECUTION
 log_args = env_helper.LOG_ARGS
